@@ -29,7 +29,7 @@ sub _clean_copyright ($c) {
 
 sub _create_or_merge ($result, $c) {
     my $st = Software::Copyright::Statement->new($c);
-    my $name = NFKD($st->name // '');
+    my $name = $st->name // '';
     if ($result->{$name}) {
         $result->{$name}->merge($st);
     }
