@@ -60,6 +60,10 @@ sub __clean_copyright ($c) {
     $c =~ s/[^a-z0-9\s,.'"]+copyright[^a-z0-9\s,.'"]+//i;
     # libuv1 has copyright like "2000, -present"
     $c =~ s![,\s]*-present!'-'.(localtime->year() + 1900)!e;
+    # texlive-extra has year range like 2023-20**
+    $c =~ s!(\d+)-2\d\*\*!"$1-".(localtime->year() + 1900)!e;
+    # texlive-extra has year range like 2011-..
+    $c =~ s!(\d+)-\.+!"$1-".(localtime->year() + 1900)!e;
     # cleanup markdown copyright
     $c =~ s/\[([\w\s]+)\]\(mailto:([\w@.+-]+)\)/$1 <$2>/;
     return $c;
